==> exo.platform.packaging.source-3.0.9.zip: cs-2.1.9/eXoApplication/calendar/service/src/main/java/org/exoplatform/calendar/service/EventCategory.java <==
/**
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 **/
package org.exoplatform.calendar.service;

import org.exoplatform.services.jcr.util.IdGenerator;


/**
 * Created by The eXo Platform SARL
 * Author : Hung Nguyen Quang
 *          hung.nguyen@exoplatform.com
 * Jul 11, 2007  
 */
public class EventCategory {
  private String id ;
  private String name ;
  private String description ;
  private boolean isDataInit = false ;
  
  public EventCategory() {
    id = "eventCategory" + IdGenerator.generate() ;
  }
  public String getName() { return name ; }
  public void   setName(String name) { this.name = name ; }

  public String getDescription() { return description ; }
  public void   setDescription(String description) { this.description = description ; }
  
	public void setDataInit(boolean isDataInit) { this.isDataInit = isDataInit ; }
	public boolean isDataInit() {	return isDataInit ;	}
  public void setId(String id) {
    this.id = id;
  }
  public String getId() {
    return id;
  }

}

==> exo.platform.packaging.source-3.5.2.zip: cs-2.2.8/eXoApplication/calendar/service/src/main/java/org/exoplatform/calendar/service/EventCategory.java <==
/**
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 **/
package org.exoplatform.calendar.service;

import org.exoplatform.services.jcr.util.IdGenerator;

/**
 * Created by The eXo Platform SARL
 * Author : Hung Nguyen Quang
 *          hung.nguyen@exoplatform.com
 * Jul 11, 2007  
 */
public class EventCategory {
  private String  id;

  private String  name;

  private String  description;

  private boolean isDataInit = false;

  public EventCategory() {
    id = "eventCategory" + IdGenerator.generate();
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public void setDataInit(boolean isDataInit) {
    this.isDataInit = isDataInit;
  }

  public boolean isDataInit() {
    return isDataInit;
  }

  public void setId(String id) {
    this.id = id;
  }

  public String getId() {
    return id;
  }

}
